@@ -31,7 +31,6 @@
 #include <KColorScheme>
 #include <KMessageBox>
 
-#include <QSplitter>
 #include <QStackedWidget>
 #include <QTabBar>
 
@@ -79,7 +78,7 @@ SieveEditorMainWidget::~SieveEditorMainWidget()
 QWidget *SieveEditorMainWidget::hasExistingPage(const QUrl &url)
 {
     for (int i = 0; i < mTabWidget->count(); ++i) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
+        auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
         if (page) {
             if (page->currentUrl() == url) {
                 return page;
@@ -112,7 +111,7 @@ void SieveEditorMainWidget::slotScriptRenamed(const QUrl &oldUrl, const QUrl &ne
 {
     QWidget *page = hasExistingPage(oldUrl);
     if (page) {
-        if (SieveEditorPageWidget *editor = qobject_cast<SieveEditorPageWidget *>(page)) {
+        if (auto *editor = qobject_cast<SieveEditorPageWidget *>(page)) {
             editor->setCurrentUrl(newUrl);
             const QString newScriptName = newUrl.fileName();
             mTabWidget->setTabText(mTabWidget->indexOf(page), newScriptName);
@@ -128,7 +127,7 @@ void SieveEditorMainWidget::slotCreateScriptPage(const KSieveUi::ManageSieveWidg
     if (page) {
         mTabWidget->setCurrentWidget(page);
     } else {
-        SieveEditorPageWidget *editor = new SieveEditorPageWidget;
+        auto *editor = new SieveEditorPageWidget;
         connect(editor, &SieveEditorPageWidget::refreshList, this, &SieveEditorMainWidget::updateScriptList);
         connect(editor, &SieveEditorPageWidget::scriptModified, this, &SieveEditorMainWidget::slotScriptModified);
         connect(editor, &SieveEditorPageWidget::modeEditorChanged, this, &SieveEditorMainWidget::modeEditorChanged);
@@ -182,7 +181,7 @@ void SieveEditorMainWidget::uploadScript()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->uploadScript();
         }
@@ -193,7 +192,7 @@ bool SieveEditorMainWidget::needToSaveScript()
 {
     bool scriptSaved = false;
     for (int i = 0; i < mTabWidget->count(); ++i) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
+        auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
         if (page) {
             const bool result = page->needToSaveScript();
             if (result) {
@@ -213,7 +212,7 @@ bool SieveEditorMainWidget::isUndoAvailable() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isUndoAvailable();
         }
@@ -225,7 +224,7 @@ bool SieveEditorMainWidget::isRedoAvailable() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isRedoAvailable();
         }
@@ -237,7 +236,7 @@ bool SieveEditorMainWidget::isWordWrap() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isWordWrap();
         }
@@ -249,7 +248,7 @@ bool SieveEditorMainWidget::hasSelection() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->hasSelection();
         }
@@ -261,7 +260,7 @@ void SieveEditorMainWidget::slotSelectAll()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->selectAll();
         }
@@ -272,7 +271,7 @@ void SieveEditorMainWidget::slotCopy()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->copy();
         }
@@ -283,7 +282,7 @@ void SieveEditorMainWidget::slotPaste()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->paste();
         }
@@ -294,7 +293,7 @@ void SieveEditorMainWidget::slotCut()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->cut();
         }
@@ -305,7 +304,7 @@ void SieveEditorMainWidget::slotUndo()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->undo();
         }
@@ -316,7 +315,7 @@ void SieveEditorMainWidget::slotRedo()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->redo();
         }
@@ -327,7 +326,7 @@ void SieveEditorMainWidget::slotGoToLine()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->goToLine();
         }
@@ -338,7 +337,7 @@ void SieveEditorMainWidget::slotFind()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->find();
         }
@@ -349,7 +348,7 @@ void SieveEditorMainWidget::slotReplace()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->replace();
         }
@@ -360,7 +359,7 @@ void SieveEditorMainWidget::slotShareScript()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->shareScript();
         }
@@ -371,7 +370,7 @@ QString SieveEditorMainWidget::currentText() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->currentText();
         }
@@ -383,7 +382,7 @@ void SieveEditorMainWidget::slotCreateRulesGraphically()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->createRulesGraphically();
         }
@@ -394,7 +393,7 @@ void SieveEditorMainWidget::slotCheckSyntax()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->checkSyntax();
         }
@@ -405,7 +404,7 @@ void SieveEditorMainWidget::slotComment()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->comment();
         }
@@ -416,7 +415,7 @@ void SieveEditorMainWidget::slotUncomment()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->uncomment();
         }
@@ -427,7 +426,7 @@ void SieveEditorMainWidget::slotImport()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->import();
         }
@@ -438,7 +437,7 @@ void SieveEditorMainWidget::slotCheckSpelling()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->checkSpelling();
         }
@@ -449,7 +448,7 @@ void SieveEditorMainWidget::slotSaveAs()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->saveAs();
         }
@@ -460,7 +459,7 @@ void SieveEditorMainWidget::slotReverseCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->reverseCase();
         }
@@ -471,7 +470,7 @@ void SieveEditorMainWidget::slotDebugSieveScript()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->debugSieveScript();
         }
@@ -482,7 +481,7 @@ void SieveEditorMainWidget::slotUpperCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->upperCase();
         }
@@ -493,7 +492,7 @@ void SieveEditorMainWidget::slotSentenceCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->sentenceCase();
         }
@@ -504,7 +503,7 @@ void SieveEditorMainWidget::slotLowerCase()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->lowerCase();
         }
@@ -526,7 +525,7 @@ void SieveEditorMainWidget::slotZoomIn()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->zoomIn();
         }
@@ -537,7 +536,7 @@ void SieveEditorMainWidget::slotZoomOut()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->zoomOut();
         }
@@ -548,7 +547,7 @@ void SieveEditorMainWidget::slotZoomReset()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->zoomReset();
         }
@@ -559,7 +558,7 @@ void SieveEditorMainWidget::slotWordWrap(bool state)
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->wordWrap(state);
         }
@@ -570,7 +569,7 @@ void SieveEditorMainWidget::slotPrintPreview()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->printPreview();
         }
@@ -581,7 +580,7 @@ void SieveEditorMainWidget::slotPrint()
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->print();
         }
@@ -600,7 +599,7 @@ void SieveEditorMainWidget::slotGeneralPaletteChanged()
 
 void SieveEditorMainWidget::forceCloseTab(int index)
 {
-    SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
+    auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
     if (page) {
         mTabWidget->removeTab(index);
         delete page;
@@ -610,7 +609,7 @@ void SieveEditorMainWidget::forceCloseTab(int index)
 
 void SieveEditorMainWidget::slotTabCloseRequested(int index)
 {
-    SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
+    auto *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(index));
     if (page) {
         if (page->isModified()) {
             const int result = KMessageBox::questionYesNoCancel(this, i18n("Script was modified. Do you want to save before closing?"), i18n("Close script"));
@@ -649,7 +648,7 @@ KSieveUi::SieveEditorWidget::EditorMode SieveEditorMainWidget::pageMode() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->pageMode();
         }
@@ -661,7 +660,7 @@ void SieveEditorMainWidget::openBookmarkUrl(const QUrl &url)
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             page->openBookmarkUrl(url);
         }
@@ -672,7 +671,7 @@ QString SieveEditorMainWidget::currentHelpTitle() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->currentHelpTitle();
         }
@@ -684,7 +683,7 @@ QUrl SieveEditorMainWidget::currentHelpUrl() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->currentHelpUrl();
         }
@@ -696,7 +695,7 @@ bool SieveEditorMainWidget::printSupportEnabled() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->printSupportEnabled();
         }
@@ -708,7 +707,7 @@ bool SieveEditorMainWidget::isTextEditor() const
 {
     QWidget *w = mTabWidget->currentWidget();
     if (w) {
-        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        auto *page = qobject_cast<SieveEditorPageWidget *>(w);
         if (page) {
             return page->isTextEditor();
         }
